==> persistence-1.1.100-sources.jar: com/xforceplus/jpa/listener/UpdaterListener.java <==
package com.xforceplus.jpa.listener;

import com.xforceplus.tenant.security.core.context.UserInfoHolder;
import com.xforceplus.tenant.security.core.domain.IAuthorizedUser;
import com.xforceplus.tenant.security.core.domain.ICreater;
import com.xforceplus.tenant.security.core.domain.IUpdater;
import org.apache.commons.lang3.StringUtils;

/***
 * @author geewit
 */
@SuppressWarnings("all")
public abstract class UpdaterListener<U extends IUpdater> {
    protected void beforeInsert(U entity) {
        IAuthorizedUser authorizedUser = UserInfoHolder.get();
        if (authorizedUser != null) {
            entity.setUpdaterId(String.valueOf(authorizedUser.getId()));
            if (authorizedUser.getOperaterName() != null) {
                entity.setUpdaterName(authorizedUser.getOperaterName());
            }
            if (entity instanceof ICreater) {
                ((ICreater) entity).setCreaterId(String.valueOf(authorizedUser.getId()));
                if (authorizedUser.getOperaterName() != null) {
                    ((ICreater) entity).setCreaterName(authorizedUser.getOperaterName());
                } else {
                    ((ICreater) entity).setCreaterName(StringUtils.EMPTY);
                }
            }
        }
    }

    protected void beforeUpdate(U entity) {
        IAuthorizedUser authorizedUser = UserInfoHolder.get();
        if (authorizedUser != null) {
            entity.setUpdaterId(String.valueOf(authorizedUser.getId()));
            if (authorizedUser.getOperaterName() != null) {
                entity.setUpdaterName(authorizedUser.getOperaterName());
            } else {
                entity.setUpdaterName(StringUtils.EMPTY);
            }
        }
    }
}

==> persistence-1.1.121-sources.jar: com/xforceplus/jpa/listener/UpdaterListener.java <==
package com.xforceplus.jpa.listener;

import com.xforceplus.tenant.security.core.context.ClientInfoHolder;
import com.xforceplus.tenant.security.core.context.UserInfoHolder;
import com.xforceplus.tenant.security.core.domain.IAuthorizedUser;
import com.xforceplus.tenant.security.core.domain.ICreater;
import com.xforceplus.tenant.security.core.domain.IUpdater;
import org.apache.commons.lang3.StringUtils;

/***
 * @author geewit
 */
@SuppressWarnings("all")
public abstract class UpdaterListener<U extends IUpdater> {
    protected void beforeInsert(U entity) {
        IAuthorizedUser authorizedUser = UserInfoHolder.get();
        if (authorizedUser != null) {
            entity.setUpdaterId(String.valueOf(authorizedUser.getId()));
            if (authorizedUser.getOperaterName() != null) {
                entity.setUpdaterName(authorizedUser.getOperaterName());
            }
            if (entity instanceof ICreater) {
                ((ICreater) entity).setCreaterId(String.valueOf(authorizedUser.getId()));
                if (authorizedUser.getOperaterName() != null) {
                    ((ICreater) entity).setCreaterName(authorizedUser.getOperaterName());
                } else {
                    ((ICreater) entity).setCreaterName(StringUtils.EMPTY);
                }
            }
        }else{
            //client token创建人和更新人设置为clientId
            String clientId = ClientInfoHolder.get();
            if (StringUtils.isNotEmpty(clientId)){
                entity.setUpdaterName(clientId);
                if (entity instanceof ICreater) {
                    ((ICreater) entity).setCreaterName(clientId);
                }
            }
        }
    }

    protected void beforeUpdate(U entity) {
        IAuthorizedUser authorizedUser = UserInfoHolder.get();
        if (authorizedUser != null) {
            entity.setUpdaterId(String.valueOf(authorizedUser.getId()));
            if (authorizedUser.getOperaterName() != null) {
                entity.setUpdaterName(authorizedUser.getOperaterName());
            } else {
                entity.setUpdaterName(StringUtils.EMPTY);
            }
        }else{
            //client token创建人和更新人设置为clientId
            String clientId = ClientInfoHolder.get();
            if (StringUtils.isNotEmpty(clientId)){
                entity.setUpdaterName(clientId);
            }
        }
    }
}
